@@ -255,6 +255,29 @@ sub _is_absolute_path {
     return $path =~ /^\// || $path =~ /^https?:\/\//;
 }
 
+sub _normalize_path_to_absolute {
+    my ($self, $asset) = @_;
+
+    # an absolute path remains unchanged
+    return $asset if $self->_is_absolute_path($asset);
+        
+    my $base = $self->base_path;
+    $base = '' if $base eq '/';
+
+    # this is a relative path, transform to its permalink
+    if ($self->is_page) {
+        return $base .
+               '/'.$self->slug .
+               '/'.$asset;
+    }
+    else {
+        return $base .
+               '/'.$self->category .
+               '/'.$self->slug .
+               '/'.$asset;
+    }
+}
+
 has image => (
     is => 'ro',
     lazy => 1,
@@ -262,25 +285,27 @@ has image => (
         my ($self) = @_;
         my $asset = $self->meta->{'image'};
         return undef if ! defined $asset;
+        return $self->_normalize_path_to_absolute($asset); 
+    },
+);
 
-        # an absolute path remains unchanged
-        return $asset if $self->_is_absolute_path($asset);
-        
-        my $base = $self->base_path;
-        $base = '' if $base eq '/';
+=head2 background
 
-        # this is a relative path, transform to its permalink
-        if ($self->is_page) {
-            return $base .
-                   '/'.$self->slug .
-                   '/'.$asset;
-        }
-        else {
-            return $base .
-                   '/'.$self->category .
-                   '/'.$self->slug .
-                   '/'.$asset;
-        }
+If defined in C<meta.yml>, this is expected to be a path to a big image that
+will be used as the background image of the whole page. 
+As with C<image>, if the path is relative, it will be transformed to 
+its absolute form, based on the Article location.
+
+=cut
+
+has background => (
+    is => 'ro',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
+        my $asset = $self->meta->{'background'};
+        return undef if ! defined $asset;
+        return $self->_normalize_path_to_absolute($asset); 
     },
 );
 
